@@ -10,16 +10,18 @@ relevant to a particular simulation. This module provides a class to wrap that
 archive file for convenient access and inspection.
 
 """
-from collections import defaultdict
-from typing import List, Dict, Any, Union
-from pathlib import Path
 import re
+import warnings
+from collections import defaultdict
+from pathlib import Path
+from typing import Any, Dict, List, Union
 
 from vivarium.framework.artifact import hdf
 
 
 class ArtifactException(Exception):
     """Exception raise for inconsistent use of the data artifact."""
+
     pass
 
 
@@ -63,8 +65,9 @@ class Artifact:
     def create_hdf_with_keyspace(self):
         """Creates the artifact HDF file and adds a node to track keys."""
         if not self._path.is_file():
+            warnings.warn(f"No artifact found at {self._path}. Building new artifact.")
             hdf.touch(self._path)
-            hdf.write(self._path, 'metadata.keyspace', ['metadata.keyspace'])
+            hdf.write(self._path, "metadata.keyspace", ["metadata.keyspace"])
 
     def load(self, entity_key: str) -> Any:
         """Loads the data associated with provided entity_key.
@@ -90,9 +93,13 @@ class Artifact:
             raise ArtifactException(f"{entity_key} should be in {self.path}.")
 
         if entity_key not in self._cache:
-            data = hdf.load(self._path, entity_key, self._filter_terms, self._draw_column_filter)
+            data = hdf.load(
+                self._path, entity_key, self._filter_terms, self._draw_column_filter
+            )
             # FIXME: Under what conditions do we get None here.
-            assert data is not None, f"Data for {entity_key} is not available. Check your model specification."
+            assert (
+                data is not None
+            ), f"Data for {entity_key} is not available. Check your model specification."
             self._cache[entity_key] = data
 
         return self._cache[entity_key]
@@ -115,9 +122,9 @@ class Artifact:
 
         """
         if entity_key in self:
-            raise ArtifactException(f'{entity_key} already in artifact.')
+            raise ArtifactException(f"{entity_key} already in artifact.")
         elif data is None:
-            raise ArtifactException(f'Attempting to write to key {entity_key} with no data.')
+            raise ArtifactException(f"Attempting to write to key {entity_key} with no data.")
         else:
             hdf.write(self._path, entity_key, data)
             self._keys.append(entity_key)
@@ -137,7 +144,9 @@ class Artifact:
 
         """
         if entity_key not in self:
-            raise ArtifactException(f'Trying to remove non-existent key {entity_key} from artifact.')
+            raise ArtifactException(
+                f"Trying to remove non-existent key {entity_key} from artifact."
+            )
 
         self._keys.remove(entity_key)
         if entity_key in self._cache:
@@ -162,7 +171,9 @@ class Artifact:
 
         """
         if entity_key not in self:
-            raise ArtifactException(f'Trying to replace non-existent key {entity_key} in artifact.')
+            raise ArtifactException(
+                f"Trying to replace non-existent key {entity_key} in artifact."
+            )
         self.remove(entity_key)
         self.write(entity_key, data)
 
@@ -188,18 +199,18 @@ class Artifact:
         key_tree = _to_tree(self.keys)
         out = "Artifact containing the following keys:\n"
         for root, children in key_tree.items():
-            out += f'{root}\n'
+            out += f"{root}\n"
             for child, grandchildren in children.items():
-                out += f'\t{child}\n'
+                out += f"\t{child}\n"
                 for grandchild in grandchildren:
-                    out += f'\t\t{grandchild}\n'
+                    out += f"\t\t{grandchild}\n"
         return out
 
 
 def _to_tree(keys: List[str]) -> Dict[str, Dict[str, List[str]]]:
     out = defaultdict(lambda: defaultdict(list))
     for k in keys:
-        key = k.split('.')
+        key = k.split(".")
         if len(key) == 3:
             out[key[0]][key[1]].append(key[2])
         else:
@@ -209,18 +220,18 @@ def _to_tree(keys: List[str]) -> Dict[str, Dict[str, List[str]]]:
 
 class Keys:
     """A convenient wrapper around the keyspace which makes it easier for
-     Artifact to maintain its keyspace when an entity key is added or removed.
-     With the artifact_path, Keys object is initialized when the Artifact is
-     initialized """
+    Artifact to maintain its keyspace when an entity key is added or removed.
+    With the artifact_path, Keys object is initialized when the Artifact is
+    initialized"""
 
-    keyspace_node = 'metadata.keyspace'
+    keyspace_node = "metadata.keyspace"
 
     def __init__(self, artifact_path: Path):
         self._path = artifact_path
-        self._keys = [str(k) for k in hdf.load(self._path, 'metadata.keyspace', None, None)]
+        self._keys = [str(k) for k in hdf.load(self._path, "metadata.keyspace", None, None)]
 
     def append(self, new_key: str):
-        """ Whenever the artifact gets a new key and new data, append is called to
+        """Whenever the artifact gets a new key and new data, append is called to
         remove the old keyspace and to write the updated keyspace"""
 
         self._keys.append(new_key)
@@ -228,7 +239,7 @@ class Keys:
         hdf.write(self._path, self.keyspace_node, self._keys)
 
     def remove(self, removing_key: str):
-        """ Whenever the artifact removes a key and data, remove is called to
+        """Whenever the artifact removes a key and data, remove is called to
         remove the key from keyspace and write the updated keyspace."""
 
         self._keys.remove(removing_key)
@@ -254,28 +265,34 @@ def _parse_draw_filters(filter_terms):
         draw_terms = []
         for term in filter_terms:
             # first strip out all the parentheses
-            t = re.sub('[()]', '', term)
+            t = re.sub("[()]", "", term)
             # then split each condition out
-            t = re.split('[&|]', t)
+            t = re.split("[&|]", t)
             # then split condition to see if it relates to draws
-            split_term = [re.split('([<=>in])', i) for i in t]
-            draw_terms.extend([t for t in split_term if t[0].strip() == 'draw'])
+            split_term = [re.split("([<=>in])", i) for i in t]
+            draw_terms.extend([t for t in split_term if t[0].strip() == "draw"])
 
         if len(draw_terms) > 1:
-            raise ValueError(f'You can only supply one filter term related to draws. '
-                             f'You supplied {filter_terms}, {len(draw_terms)} of which pertain to draws.')
+            raise ValueError(
+                f"You can only supply one filter term related to draws. "
+                f"You supplied {filter_terms}, {len(draw_terms)} of which pertain to draws."
+            )
 
         if draw_terms:
             # convert term to columns
             term = [s.strip() for s in draw_terms[0] if s.strip()]
-            if len(term) == 4 and term[1].lower() == 'i' and term[2].lower() == 'n':
-                draws = [int(d) for d in term[-1][1:-1].split(',')]
-            elif (len(term) == 4 and term[1] == term[2] == '=') or (len(term) == 3 and term[1] == '='):
+            if len(term) == 4 and term[1].lower() == "i" and term[2].lower() == "n":
+                draws = [int(d) for d in term[-1][1:-1].split(",")]
+            elif (len(term) == 4 and term[1] == term[2] == "=") or (
+                len(term) == 3 and term[1] == "="
+            ):
                 draws = [int(term[-1])]
             else:
-                raise NotImplementedError(f'The only supported draw filters are =, ==, or in. '
-                                          f'You supplied {"".join(term)}.')
+                raise NotImplementedError(
+                    f"The only supported draw filters are =, ==, or in. "
+                    f'You supplied {"".join(term)}.'
+                )
 
-            columns = [f'draw_{n}' for n in draws] + ['value']
+            columns = [f"draw_{n}" for n in draws] + ["value"]
 
     return columns
