@@ -17,9 +17,9 @@ setup everything it holds when the context itself is setup.
 """
 import inspect
 import typing
-from typing import Union, List, Tuple, Iterator, Dict, Any, Type
+from typing import Any, Dict, Iterator, List, Tuple, Type, Union
 
-from vivarium.config_tree import DuplicatedConfigurationError, ConfigurationError
+from vivarium.config_tree import ConfigurationError, DuplicatedConfigurationError
 from vivarium.exceptions import VivariumError
 
 if typing.TYPE_CHECKING:
@@ -28,6 +28,7 @@ if typing.TYPE_CHECKING:
 
 class ComponentConfigError(VivariumError):
     """Error while interpreting configuration file or initializing components"""
+
     pass
 
 
@@ -46,7 +47,9 @@ class OrderedComponentSet:
 
     def add(self, component: Any):
         if component in self:
-            raise ComponentConfigError(f"Attempting to add a component with duplicate name: {component}")
+            raise ComponentConfigError(
+                f"Attempting to add a component with duplicate name: {component}"
+            )
         self.components.append(component)
 
     def update(self, components: Union[List[Any], Tuple[Any]]):
@@ -71,12 +74,14 @@ class OrderedComponentSet:
     def __bool__(self) -> bool:
         return bool(self.components)
 
-    def __add__(self, other: 'OrderedComponentSet') -> 'OrderedComponentSet':
+    def __add__(self, other: "OrderedComponentSet") -> "OrderedComponentSet":
         return OrderedComponentSet(*(self.components + other.components))
 
-    def __eq__(self, other: 'OrderedComponentSet') -> bool:
+    def __eq__(self, other: "OrderedComponentSet") -> bool:
         try:
-            return type(self) is type(other) and [c.name for c in self.components] == [c.name for c in other.components]
+            return type(self) is type(other) and [c.name for c in self.components] == [
+                c.name for c in other.components
+            ]
         except TypeError:
             return False
 
@@ -120,10 +125,16 @@ class ComponentManager:
         self.configuration = configuration
         self.lifecycle = lifecycle_manager
 
-        self.lifecycle.add_constraint(self.get_components_by_type,
-                                      restrict_during=['initialization', 'population_creation'])
-        self.lifecycle.add_constraint(self.get_component, restrict_during=['population_creation'])
-        self.lifecycle.add_constraint(self.list_components, restrict_during=['initialization'])
+        self.lifecycle.add_constraint(
+            self.get_components_by_type,
+            restrict_during=["initialization", "population_creation"],
+        )
+        self.lifecycle.add_constraint(
+            self.get_component, restrict_during=["population_creation"]
+        )
+        self.lifecycle.add_constraint(
+            self.list_components, restrict_during=["initialization"]
+        )
 
     def add_managers(self, managers: Union[List[Any], Tuple[Any]]):
         """Registers new managers with the component manager.
@@ -155,7 +166,9 @@ class ComponentManager:
             self.apply_configuration_defaults(c)
             self._components.add(c)
 
-    def get_components_by_type(self, component_type: Union[type, Tuple[type, ...]]) -> List[Any]:
+    def get_components_by_type(
+        self, component_type: Union[type, Tuple[type, ...]]
+    ) -> List[Any]:
         """Get all components that are an instance of ``component_type``.
 
         Parameters
@@ -208,7 +221,7 @@ class ComponentManager:
         """
         return {c.name: c for c in self._components}
 
-    def setup_components(self, builder: 'Builder'):
+    def setup_components(self, builder: "Builder"):
         """Separately configure and set up the managers and components held by
         the component manager, in that order.
 
@@ -226,32 +239,39 @@ class ComponentManager:
         self._setup_components(builder, self._managers + self._components)
 
     def apply_configuration_defaults(self, component: Any):
-        if not hasattr(component, 'configuration_defaults'):
+        if not hasattr(component, "configuration_defaults"):
             return
         try:
-            self.configuration.update(component.configuration_defaults,
-                                      layer='component_configs', source=component.name)
+            self.configuration.update(
+                component.configuration_defaults,
+                layer="component_configs",
+                source=component.name,
+            )
         except DuplicatedConfigurationError as e:
             new_name, new_file = component.name, self._get_file(component)
             old_name, old_file = e.source, self._get_file(self.get_component(e.source))
 
-            raise ComponentConfigError(f'Component {new_name} in file {new_file} is attempting to '
-                                       f'set the configuration value {e.value_name}, but it has already '
-                                       f'been set by {old_name} in file {old_file}.')
+            raise ComponentConfigError(
+                f"Component {new_name} in file {new_file} is attempting to "
+                f"set the configuration value {e.value_name}, but it has already "
+                f"been set by {old_name} in file {old_file}."
+            )
         except ConfigurationError as e:
             new_name, new_file = component.name, self._get_file(component)
-            raise ComponentConfigError(f'Component {new_name} in file {new_file} is attempting to '
-                                       f'alter the structure of the configuration at key {e.value_name}. '
-                                       f'This happens if one component attempts to set a value at an interior '
-                                       f'configuration key or if it attempts to turn an interior key into a '
-                                       f'configuration value.')
+            raise ComponentConfigError(
+                f"Component {new_name} in file {new_file} is attempting to "
+                f"alter the structure of the configuration at key {e.value_name}. "
+                f"This happens if one component attempts to set a value at an interior "
+                f"configuration key or if it attempts to turn an interior key into a "
+                f"configuration value."
+            )
 
     @staticmethod
     def _get_file(component):
-        if component.__module__ == '__main__':
+        if component.__module__ == "__main__":
             # This is defined directly in a script or notebook so there's no
             # file to attribute it to.
-            return '__main__'
+            return "__main__"
         else:
             return inspect.getfile(component.__class__)
 
@@ -264,15 +284,15 @@ class ComponentManager:
             if isinstance(current, (list, tuple)):
                 components.extend(current[::-1])
             else:
-                if hasattr(current, 'sub_components'):
+                if hasattr(current, "sub_components"):
                     components.extend(current.sub_components[::-1])
                 out.append(current)
         return out
 
     @staticmethod
-    def _setup_components(builder: 'Builder', components: OrderedComponentSet):
+    def _setup_components(builder: "Builder", components: OrderedComponentSet):
         for c in components:
-            if hasattr(c, 'setup'):
+            if hasattr(c, "setup"):
                 c.setup(builder)
 
     def __repr__(self):
@@ -305,7 +325,9 @@ class ComponentInterface:
         """
         return self._manager.get_component(name)
 
-    def get_components_by_type(self, component_type: Union[type, Tuple[type, ...]]) -> List[Any]:
+    def get_components_by_type(
+        self, component_type: Union[type, Tuple[type, ...]]
+    ) -> List[Any]:
         """Get all components that are an instance of ``component_type``.
 
         Parameters
