@@ -1,20 +1,24 @@
 import pytest
 
-from vivarium.framework.engine import SimulationContext, Builder
-from vivarium.framework.artifact import ArtifactManager, ArtifactInterface
-from vivarium.framework.event import EventManager, EventInterface
-from vivarium.framework.lifecycle import LifeCycleManager, LifeCycleInterface
-from vivarium.framework.lookup import LookupTableManager, LookupTableInterface
-from vivarium.framework.components import OrderedComponentSet, ComponentManager, ComponentInterface
+from vivarium.framework.artifact import ArtifactInterface, ArtifactManager
+from vivarium.framework.components import (
+    ComponentInterface,
+    ComponentManager,
+    OrderedComponentSet,
+)
+from vivarium.framework.engine import Builder, SimulationContext
+from vivarium.framework.event import EventInterface, EventManager
+from vivarium.framework.lifecycle import LifeCycleInterface, LifeCycleManager
+from vivarium.framework.lookup import LookupTableInterface, LookupTableManager
 from vivarium.framework.metrics import Metrics
-from vivarium.framework.population import PopulationManager, PopulationInterface
-from vivarium.framework.randomness import RandomnessManager, RandomnessInterface
-from vivarium.framework.resource import ResourceManager, ResourceInterface
-from vivarium.framework.results import ResultsManager, ResultsInterface
+from vivarium.framework.population import PopulationInterface, PopulationManager
+from vivarium.framework.randomness import RandomnessInterface, RandomnessManager
+from vivarium.framework.resource import ResourceInterface, ResourceManager
+from vivarium.framework.results import ResultsInterface, ResultsManager
 from vivarium.framework.time import DateTimeClock, TimeInterface
-from vivarium.framework.values import ValuesManager, ValuesInterface
+from vivarium.framework.values import ValuesInterface, ValuesManager
 
-from .components.mocks import MockComponentA, MockComponentB, Listener
+from .components.mocks import Listener, MockComponentA, MockComponentB
 
 
 def is_same_object_method(m1, m2):
@@ -23,14 +27,16 @@ def is_same_object_method(m1, m2):
 
 @pytest.fixture
 def components():
-    return [MockComponentA('gretchen', 'whimsy'),
-            Listener('listener'),
-            MockComponentB('spoon', 'antelope', 23)]
+    return [
+        MockComponentA("gretchen", "whimsy"),
+        Listener("listener"),
+        MockComponentB("spoon", "antelope", 23),
+    ]
 
 
 @pytest.fixture
 def log(mocker):
-    return mocker.patch('vivarium.framework.engine.logger')
+    return mocker.patch("vivarium.framework.engine.logger")
 
 
 def test_SimulationContext_init_default(components):
@@ -75,14 +81,23 @@ def test_SimulationContext_init_default(components):
     assert sim._builder.data._manager is sim._data
 
     # Ordering matters.
-    managers = [sim._clock, sim._lifecycle, sim._resource, sim._values,
-                sim._population, sim._randomness, sim._events,
-                sim._tables, sim._data, sim._results]
+    managers = [
+        sim._clock,
+        sim._lifecycle,
+        sim._resource,
+        sim._values,
+        sim._population,
+        sim._randomness,
+        sim._events,
+        sim._tables,
+        sim._data,
+        sim._results,
+    ]
     assert sim._component_manager._managers == OrderedComponentSet(*managers)
     unpacked_components = []
     for c in components:
         unpacked_components.append(c)
-        if hasattr(c, 'sub_components'):
+        if hasattr(c, "sub_components"):
             unpacked_components.extend(c.sub_components)
     assert list(sim._component_manager._components)[:-1] == unpacked_components
     assert isinstance(list(sim._component_manager._components)[-1], Metrics)
@@ -90,28 +105,37 @@ def test_SimulationContext_init_default(components):
 
 def test_SimulationContext_setup_default(base_config, components):
     sim = SimulationContext(base_config, components)
-    listener = [c for c in components if 'listener' in c.args][0]
+    listener = [c for c in components if "listener" in c.args][0]
     assert not listener.post_setup_called
     sim.setup()
 
     unpacked_components = []
     for c in components:
         unpacked_components.append(c)
-        if hasattr(c, 'sub_components'):
+        if hasattr(c, "sub_components"):
             unpacked_components.extend(c.sub_components)
     unpacked_components.append(Metrics())
 
     for a, b in zip(sim._component_manager._components, unpacked_components):
         assert type(a) == type(b)
-        if hasattr(a, 'args'):
+        if hasattr(a, "args"):
             assert a.args == b.args
 
     assert is_same_object_method(sim.simulant_creator, sim._population._create_simulants)
-    assert sim.time_step_events == ['time_step__prepare', 'time_step', 'time_step__cleanup', 'collect_metrics']
+    assert sim.time_step_events == [
+        "time_step__prepare",
+        "time_step",
+        "time_step__cleanup",
+        "collect_metrics",
+    ]
     for k in sim.time_step_emitters.keys():
-        assert is_same_object_method(sim.time_step_emitters[k], sim._events._event_types[k].emit)
+        assert is_same_object_method(
+            sim.time_step_emitters[k], sim._events._event_types[k].emit
+        )
 
-    assert is_same_object_method(sim.end_emitter, sim._events._event_types['simulation_end'].emit)
+    assert is_same_object_method(
+        sim.end_emitter, sim._events._event_types["simulation_end"].emit
+    )
 
     assert listener.post_setup_called
 
@@ -135,7 +159,7 @@ def test_SimulationContext_step(log, base_config, components):
     current_time = sim._clock.time
     step_size = sim._clock.step_size
 
-    listener = [c for c in components if 'listener' in c.args][0]
+    listener = [c for c in components if "listener" in c.args][0]
 
     assert not listener.time_step__prepare_called
     assert not listener.time_step_called
@@ -155,7 +179,7 @@ def test_SimulationContext_step(log, base_config, components):
 
 def test_SimulationContext_finalize(base_config, components):
     sim = SimulationContext(base_config, components)
-    listener = [c for c in components if 'listener' in c.args][0]
+    listener = [c for c in components if "listener" in c.args][0]
     sim.setup()
     sim.initialize_simulants()
     sim.step()
@@ -171,4 +195,6 @@ def test_SimulationContext_report(base_config, components):
     sim.run()
     sim.finalize()
     metrics = sim.report()
-    assert metrics['test'] == len([c for c in sim._component_manager._components if isinstance(c, MockComponentB)])
+    assert metrics["test"] == len(
+        [c for c in sim._component_manager._components if isinstance(c, MockComponentB)]
+    )
